<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+14"/>
        <source>About Transmission</source>
        <translation>Transmissioni buruz</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Copyright © The Transmission Project</source>
        <translation>Copyright © Transmission Proiektua</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>BitTorrent bezero azkar eta erraz bat</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cc" line="+37"/>
        <source>Client</source>
        <translation>Bezeroa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Server</source>
        <translation>Zerbitzaria</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>C&amp;redits</source>
        <translation>&amp;Kredituak</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;License</source>
        <translation>&amp;Lizentzia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Credits</source>
        <translation>Kredituak</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message numerus="yes">
        <location filename="../Application.cc" line="+313"/>
        <source>Torrent(s) Completed</source>
        <translation>
            <numerusform>Osatutako Torrent-a</numerusform>
            <numerusform>Osatutako Torrent-ak</numerusform>
        </translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Torrent Added</source>
        <translation>Torrenta Gehituta</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../DetailsDialog.cc" line="+469"/>
        <source>None</source>
        <translation>Ezer ez</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Nahastua</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+268"/>
        <source>Unknown</source>
        <translation>Ezezaguna</translation>
    </message>
    <message>
        <location line="-210"/>
        <source>Finished</source>
        <translation>Amaituta</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Pausatuta</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>%1 (+%2 discarded after failed checksum)</source>
        <translation>%1 (+%2 baztertuta checksum egiaztatzeak huts egin ondoren)</translation>
    </message>
    <message>
        <location line="+130"/>
        <source>Active now</source>
        <translation>Martxan orain</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 ago</source>
        <translation>Duela %1</translation>
    </message>
    <message numerus="yes">
        <location line="+63"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%Ln atal @ %2)</numerusform>
            <numerusform>%1 (%Ln zati @ %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%Ln atal)</numerusform>
            <numerusform>%1 (%Ln zati)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Aztarnari honen pribatua -- DHT eta PEX desgaituta</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Public torrent</source>
        <translation>Torrent publikoa</translation>
    </message>
    <message>
        <location line="+102"/>
        <source>Created by %1</source>
        <translation>Sortzailea: %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created on %1</source>
        <translation>Sortze-data: %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created by %1 on %2</source>
        <translation>%1 erabiltzaileak sortuta data honetan: %2</translation>
    </message>
    <message>
        <location line="+207"/>
        <location line="+47"/>
        <source>Encrypted connection</source>
        <translation>Zifratutako konexioa</translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Optimistic unchoke</source>
        <translation>Buxadura kentze baikorra</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading from this peer</source>
        <translation>Kide honengandik deskargatzen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Kide honetatik deskargatuko genuke beraiek utziz gero</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Uploading to peer</source>
        <translation>Kide batera igotzen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Kide honetara igoko genuke beraiek galdetuz gero</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>Kideak buxadura kendu digu, baina ez gaude interesatuta</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Kide honi buxadura kendu diogu, baina ez daude interesatuta</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer was discovered through DHT</source>
        <translation>Kidea DHT bidez aurkitu zen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>Kidea Kide-Trukaketa bidez (PEX) aurkitu zen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is an incoming connection</source>
        <translation>Kidea barrurako konexio bat da</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is connected over µTP</source>
        <translation>Kidea µTP bitartez konektatuta dago</translation>
    </message>
    <message>
        <location line="+161"/>
        <source>Add tracker announce URLs, one per line:</source>
        <translation>Gehitu aztarnari iragarle URLak, bat errenkada bakoitzean:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Error</source>
        <translation>Errorea</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No new URLs found.</source>
        <translation>Ez da URL berririk aurkitu.</translation>
    </message>
    <message>
        <location line="-872"/>
        <source>%1 (100%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data</extracomment>
        <translation>%1 (100%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data, %2 is overall size of torrent data, %3 is percentage (%1/%2*100)</extracomment>
        <translation>%1 --&gt; %2 (%3%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded data (both verified and unverified), %2 is overall size of torrent data, %3 is percentage (%1/%2*100), %4 is amount of downloaded but not yet verified data</extracomment>
        <translation>%1 --&gt; %2 (%3%), %4 Egiaztatu gabea</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>%1 (Ratio: %2)</source>
        <translation>%1 (Maila: %2)</translation>
    </message>
    <message>
        <location line="+303"/>
        <location line="+55"/>
        <source>N/A</source>
        <translation>E/G</translation>
    </message>
    <message numerus="yes">
        <location line="+358"/>
        <source>%1 minute(s)</source>
        <extracomment>Spin box format, &quot;Stop seeding if idle for: [ 5 minutes ]&quot;</extracomment>
        <translation>
            <numerusform>minutu %1</numerusform>
            <numerusform>%1 minutu</numerusform>
        </translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Add URL(s)</source>
        <translation>Gehitu URLa(k)</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>High</source>
        <translation>Altua</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baxua</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+4"/>
        <source>Use Global Settings</source>
        <translation>Erabili Ezarpen Orokorrak</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Seed regardless of ratio</source>
        <translation>Igorri maila kontuan izan gabe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Gelditu igortzen maila honetan:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Seed regardless of activity</source>
        <translation>Igorri jarduera kontuan izan gabe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for:</source>
        <translation>Gelditu igortzen geratuta badago:</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Up</source>
        <translation>Igortzen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Deskargatzen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Egoera</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Helbidea</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Bezeroa</translation>
    </message>
    <message>
        <location filename="../DetailsDialog.ui" line="+14"/>
        <source>Torrent Properties</source>
        <translation>Torrent-aren Ezaugarriak</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Information</source>
        <translation>Informazioa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Activity</source>
        <translation>Jarduera</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Have:</source>
        <translation>Dauka:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Availability:</source>
        <translation>Eskuragarritasuna:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Uploaded:</source>
        <translation>Igorritakoa:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Downloaded:</source>
        <translation>Deskargatuta:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>State:</source>
        <translation>Egoera:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Running time:</source>
        <translation>Exekuzio denbora:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Remaining time:</source>
        <translation>Gelditzen den denbora:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Last activity:</source>
        <translation>Azken jarduera:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Error:</source>
        <translation>Errorea:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Details</source>
        <translation>Xehetasunak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size:</source>
        <translation>Tamaina:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Location:</source>
        <translation>Kokalekua:</translation>
    </message>
    <message>
        <location line="+154"/>
        <source>Labels:</source>
        <translation>Etiketak:</translation>
    </message>
    <message>
        <location line="-122"/>
        <source>Hash:</source>
        <translation>Hash-a:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Privacy:</source>
        <translation>Pribatutasuna:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Origin:</source>
        <translation>Jatorria:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Added:</source>
        <translation>Gehitze-data:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Comment:</source>
        <translation>Iruzkina:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Peers</source>
        <translation>Kideak</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tracker</source>
        <translation>Aztarnaria</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Show &amp;more details</source>
        <translation>Erakutsi &amp;xehetasun gehiago</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show &amp;backup trackers</source>
        <translation>Erakutsi &amp;segurtasun-kopiako aztarnariak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Files</source>
        <translation>Fitxategiak</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Options</source>
        <translation>Aukerak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Speed</source>
        <translation>Abiadura</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Honor global &amp;limits</source>
        <translation>&amp;Bete muga orokorrak</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Limit &amp;download speed:</source>
        <translation>&amp;Mugatu deskargaren abiadura:</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Limit &amp;upload speed:</source>
        <translation>M&amp;ugatu igoeraren abiadura:</translation>
    </message>
    <message>
        <location line="-100"/>
        <source>Add</source>
        <translation>Gehitu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Edit</source>
        <translation>Editatu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Remove</source>
        <translation>Kendu</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Torrent &amp;priority:</source>
        <translation>&amp;Torrent lehentasuna:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Seeding Limits</source>
        <translation>Igortze-Mugak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Ratio:</source>
        <translation>M&amp;aila:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>&amp;Idle:</source>
        <translation>&amp;Geratuta:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Peer Connections</source>
        <translation>Kideen Konexioak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Maximum peers:</source>
        <translation>&amp;Gehienezko kide kopurua:</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../FileTreeItem.cc" line="+279"/>
        <location filename="../FileTreeView.cc" line="+110"/>
        <location line="+258"/>
        <source>Low</source>
        <translation>Baxua</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-258"/>
        <location line="+256"/>
        <source>High</source>
        <translation>Altua</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-256"/>
        <location line="+257"/>
        <source>Normal</source>
        <translation>Normala</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-256"/>
        <source>Mixed</source>
        <translation>Nahastua</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location filename="../FileTreeModel.cc" line="+203"/>
        <source>File</source>
        <translation>Fitxategia</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Size</source>
        <translation>Tamaina</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Progress</source>
        <translation>Aurrerapena</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Download</source>
        <translation>Deskargatu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Priority</source>
        <translation>Lehentasuna</translation>
    </message>
</context>
<context>
    <name>FileTreeView</name>
    <message>
        <location filename="../FileTreeView.cc" line="+248"/>
        <source>Check Selected</source>
        <translation>Aukeratu Hautatua</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uncheck Selected</source>
        <translation>Desaukeratu Hautatua</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Only Check Selected</source>
        <translation>Aukeratu Hautatua Bakarrik</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Priority</source>
        <translation>Lehentasuna</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open</source>
        <translation>Ireki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rename…</source>
        <translation>Berrizendatu…</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../FilterBar.cc" line="+47"/>
        <location line="+138"/>
        <source>All</source>
        <translation>Denak</translation>
    </message>
    <message>
        <location line="-125"/>
        <source>Active</source>
        <translation>Martxan</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Downloading</source>
        <translation>Deskargatzen</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Seeding</source>
        <translation>Igortzen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Paused</source>
        <translation>Pausatuta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Finished</source>
        <translation>Amaituta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Verifying</source>
        <translation>Egiaztatzen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Error</source>
        <translation>Errorea</translation>
    </message>
    <message>
        <location line="+142"/>
        <source>Show:</source>
        <translation>Erakutsi:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Search…</source>
        <translation>Bilatu…</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../Formatter.cc" line="+19"/>
        <location line="+25"/>
        <source>Unknown</source>
        <translation>Ezezaguna</translation>
    </message>
    <message>
        <location line="-20"/>
        <location line="+10"/>
        <location line="+19"/>
        <source>None</source>
        <translation>Ezer ez</translation>
    </message>
    <message numerus="yes">
        <location line="+30"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%Ln egun</numerusform>
            <numerusform>%Ln egun</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-5"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln ordu</numerusform>
            <numerusform>%Ln ordu</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minutu</numerusform>
            <numerusform>%Ln minutu</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%Ln segundu</numerusform>
            <numerusform>%Ln segundu</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FreeSpaceLabel</name>
    <message>
        <location filename="../FreeSpaceLabel.cc" line="+58"/>
        <source>&lt;i&gt;Calculating Free Space…&lt;/i&gt;</source>
        <translation>&lt;i&gt;Libre dagoen Espazioa kalkulatzen…&lt;/i&gt;</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>%1 free</source>
        <translation>%1 libre</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../LicenseDialog.ui" line="+14"/>
        <source>License</source>
        <translation>Lizentzia</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+181"/>
        <source>&amp;Torrent</source>
        <translation>&amp;Torrenta</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editatu</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>&amp;Laguntza</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>&amp;Ikusi</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxategia</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Create a new torrent</source>
        <translation>Sortu torrent berri bat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Properties</source>
        <translation>&amp;Ezaugarriak</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Erakutsi torrentaren ezaugarriak</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Ireki torrentaren agiritegia</translation>
    </message>
    <message>
        <location line="-161"/>
        <source>Queue</source>
        <translation>Ilara</translation>
    </message>
    <message>
        <location line="-132"/>
        <source>Options</source>
        <translation>Aukerak</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>Statistics</source>
        <translation>Estatistikak</translation>
    </message>
    <message>
        <location line="+171"/>
        <source>&amp;Open…</source>
        <translation>&amp;Ireki</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>Ireki</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>Ireki torrent bat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;New…</source>
        <translation>&amp;Berria…</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Open Fold&amp;er</source>
        <translation>&amp;Ireki Karpeta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Start</source>
        <translation>&amp;Hasi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Hasi torrenta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>&amp;Eskatu Aztarnariari Kide Gehiago</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Eskatu aztarnariari kide gehiago</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausatu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Pausatu torrenta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Verify Local Data</source>
        <translation>Egiaztatu Datuak &amp;Lokalak</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Egiaztatu datu lokalak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Remove</source>
        <translation>&amp;Kendu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Kendu torrenta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>E&amp;zabatu Fitxategiak eta Kendu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Kendu torrenta eta ezabatu dagozkion fitxategiak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Start All</source>
        <translation>&amp;Hasi Denak</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>&amp;Pausatu Denak</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>It&amp;xi</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Select All</source>
        <translation>Hautatu &amp;Denak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Deselect All</source>
        <translation>&amp;Deshautatu Denak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Hobespenak</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Ikuspegi Trinkoa</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Ikuspegi Trinkoa</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Tresnabarra</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>I&amp;ragazkibarra</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Egoerabarra</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Ordenatu &amp;Jardueraren arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Ordenatu &amp;Adinaren arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Ordenatu Gelditzen den &amp;Denboraz</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Ordenatu I&amp;zenaren arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Ordenatu &amp;Aurrerapenaren arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Ordenatu &amp;Ratioaren arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Ordenatu &amp;Tamainaren arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Ordenatu &amp;Egoeraren arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Ordenatu Az&amp;tarnarien arabera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>Mezuen &amp;Erregistroa</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>&amp;Estatistikak</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>Ed&amp;ukiak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;About</source>
        <translation>Honi &amp;Buruz</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>Alderantzikatu Ordenatze &amp;Irizpidea</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>&amp;Izena</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>&amp;Fitxategiak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>A&amp;ztarnaria</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Maila guztira</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Saioaren maila</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Transferentziak Guztira</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Saioaren Transferentziak</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>Leiho &amp;Nagusia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>Erretilu &amp;Ikonoa</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session…</source>
        <translation>&amp;Aldatu Saioa…</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set &amp;Location…</source>
        <translation>Zehaztu &amp;Kokapena…</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;URL…</source>
        <translation>Ireki &amp;URLa…</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Hautatu Saioa</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>Kopiatu &amp;Magnet Esteka Arbelera</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Donate</source>
        <translation>&amp;Dirulaguntza</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>Hasi &amp;Orain</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>Ezikusi ilara eta hasi orain</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Move to &amp;Top</source>
        <translation>Mugitu &amp;Goraino</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>Mugitu G&amp;ora</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move &amp;Down</source>
        <translation>Mugitu B&amp;ehera</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Bottom</source>
        <translation>Mugitu &amp;Beheraino</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>Ordenatu &amp;Ilararen arabera</translation>
    </message>
    <message>
        <location filename="../MainWindow.cc" line="+385"/>
        <source>Limit Download Speed</source>
        <translation>Mugatu Deskargatze-Abiadura</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Unlimited</source>
        <translation>Mugagabea</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+812"/>
        <location line="+9"/>
        <source>Limited at %1</source>
        <translation>Muga: %1</translation>
    </message>
    <message>
        <location line="-766"/>
        <source>Limit Upload Speed</source>
        <translation>Mugatu Igotze-Abiadura</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Gelditu Igortzen Maila honetan</translation>
    </message>
    <message>
        <location line="-40"/>
        <source>Seed Forever</source>
        <translation>Igorri Etengabe</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+799"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Gelditu Maila honetan (%1)</translation>
    </message>
    <message>
        <location line="-448"/>
        <source> - %1:%2</source>
        <extracomment>Second (optional) part of main window title &quot;Transmission - host:port&quot; (added when connected to remote session) notice that leading space (before the dash) is included here</extracomment>
        <translation> - %1:%2</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Idle</source>
        <translation>Geratuta</translation>
    </message>
    <message>
        <location line="+26"/>
        <location line="+19"/>
        <source>Ratio: %1</source>
        <translation>Maila: %1</translation>
    </message>
    <message>
        <location line="-14"/>
        <location line="+7"/>
        <source>Down: %1, Up: %2</source>
        <translation>Deskarga: %1, Igoera: %2</translation>
    </message>
    <message>
        <location line="+480"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Torrent Fitxategiak (*.torrent);;Fitxategi Guztiak (*.*)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;options dialog</source>
        <translation>Erakutsi a&amp;ukeren leihoa</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Open Torrent</source>
        <translation>Ireki Torrenta</translation>
    </message>
    <message>
        <location line="-1066"/>
        <source>Speed Limits</source>
        <translation>Abiadura Mugak</translation>
    </message>
    <message>
        <location line="+546"/>
        <source>Network Error</source>
        <translation>Errorea sarean</translation>
    </message>
    <message>
        <location line="+489"/>
        <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Egin klik Aldi baterako Abiadura Mugak desgaitzeko
 (%1 deskarga, %2 igoera)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Egin klik Aldi baterako Abiadura Mugak gaitzeko
 (%1 deskarga, %2 igoera)</translation>
    </message>
    <message>
        <location line="+160"/>
        <source>Remove torrent?</source>
        <translation>Kendu torrenta?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>Ezabatu deskargatutako torrent honen fitxategiak?</translation>
    </message>
    <message numerus="yes">
        <location line="-4"/>
        <source>Remove %Ln torrent(s)?</source>
        <translation>
            <numerusform>Kendu %Ln torrent?</numerusform>
            <numerusform>Kendu %Ln torrent?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-584"/>
        <source>Showing %L1 of %Ln torrent(s)</source>
        <translation>
            <numerusform>Erakusten %L1 -&gt; %Ln torrent</numerusform>
            <numerusform> %L1 erakusten guztirako %Ln torrent-etik</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+589"/>
        <source>Delete these %Ln torrent(s)&apos; downloaded files?</source>
        <translation>
            <numerusform>Ezabatu jeitsitako %Ln torrent hauen agiriak?</numerusform>
            <numerusform>Ezabatu deskargatutako %Ln torrent hauen fitxategiak?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Behin kenduta, transferentziarekin jarraitzeko torrent fitxategia edo magnet lotura beharko duzu.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Behin kenduta, transferentziekin jarraitzeko torrent fitxategiak edo magnet loturak beharko dituzu.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent has not finished downloading.</source>
        <translation>Torrent honek ez du deskarga amaitu.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>Torrent hauek ez dute deskarga amaitu.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent is connected to peers.</source>
        <translation>Torrent hau kideetara konektatuta dago.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>These torrents are connected to peers.</source>
        <translation>Torrent hauek kideetara konektatuta daude.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Torrent hauetako bat kideetara konektatuta dago.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Torrent hauetako batzuk kideetara konektatuta daude.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Torrent hauetako batek ez du deskarga amaitu.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Torrent hauetako batzuk ez dute deskarga amaitu.</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>%1 has not responded yet</source>
        <translation>%1 ez du oraindik erantzun</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is responding</source>
        <translation>%1 erantzuten ari da</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 last responded %2 ago</source>
        <translation>%1 azken erantzuna duela %2 egin zuen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is not responding</source>
        <translation>%1 ez du erantzuten</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../MakeDialog.ui" line="+17"/>
        <source>New Torrent</source>
        <translation>Torrent Berria</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="+305"/>
        <source>&lt;i&gt;No source selected&lt;/i&gt;</source>
        <translation>&lt;i&gt;Ez dago jatorririk hautatuta&lt;/i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln Agiri</numerusform>
            <numerusform>%Ln Fitxategi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln Atal</numerusform>
            <numerusform>%LnZati</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 -&gt; %2; %3 @ %4</translation>
    </message>
    <message>
        <location filename="../MakeDialog.ui" line="+6"/>
        <source>Files</source>
        <translation>Fitxategiak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Sa&amp;ve to:</source>
        <translation>&amp;Gorde hemen:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Source f&amp;older:</source>
        <translation>Jatorrizko &amp;karpeta:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Source &amp;file:</source>
        <translation>Jatorrizko &amp;Fitxategia:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Piece s&amp;ize:</source>
        <translation>Zatiaren tamaina</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Properties</source>
        <translation>Ezaugarriak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Trackers:</source>
        <translation>A&amp;ztarnariak:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Segurtasun-kopiarako URL bat gehitzeko, URL nagusiaren ondorengo errenkadan gehitu ezazu.
Beste URL nagusi bat gehitzeko, errenkada huts baten ondoren gehitu ezazu.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Co&amp;mment:</source>
        <translation>&amp;Iruzkina:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Source:</source>
        <translation>&amp;Jatorria:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Private torrent</source>
        <translation>&amp;Torrent pribatua</translation>
    </message>
</context>
<context>
    <name>MakeProgressDialog</name>
    <message>
        <location filename="../MakeProgressDialog.ui" line="+14"/>
        <source>New Torrent</source>
        <translation>Torrent Berria</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="-182"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>&quot;%1&quot; sortzen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>&quot;%1&quot; sortuta!</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Couldn&apos;t create &quot;%1&quot;: %2 (%3)</source>
        <translation>Ezin izan da sortu &quot;%1&quot;: %2 (%3)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../OptionsDialog.cc" line="+53"/>
        <source>Open Torrent</source>
        <translation>Ireki Torrenta</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Open Torrent from File</source>
        <translation>Ireki Torrenta Fitxategitik</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open Torrent from URL or Magnet Link</source>
        <translation>Ireki Torrenta URLtik edo Magnet Loturatik</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+17"/>
        <source>&amp;Source:</source>
        <translation>&amp;Jatorria:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Destination folder:</source>
        <translation>&amp;Helmugako karpeta:</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="+49"/>
        <source>High</source>
        <translation>Altua</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Baxua</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+35"/>
        <source>&amp;Priority:</source>
        <translation>&amp;Lehentasuna:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>S&amp;tart when added</source>
        <translation>H&amp;asi gehitutakoan</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>&amp;Mugitu .torrent fitxategia zakarrontzira</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="-40"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Torrent Fitxategiak (*.torrent);;Fitxategi Guztiak (*.*)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Select Destination</source>
        <translation>Hautatu Helmuga</translation>
    </message>
</context>
<context>
    <name>PathButton</name>
    <message>
        <location filename="../PathButton.cc" line="+23"/>
        <location line="+67"/>
        <source>(None)</source>
        <translation>(Ezer ez)</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Select Folder</source>
        <translation>Hautatu Karpeta</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Select File</source>
        <translation>Hautatu Fitxategia</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../PrefsDialog.ui" line="+971"/>
        <source>Use &amp;authentication</source>
        <translation>E&amp;rabili autentifikazioa</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Username:</source>
        <translation>&amp;Erabiltzaile-izena:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>&amp;Pasahitza:</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>&amp;Open web client</source>
        <translation>&amp;Ireki web bezeroa</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Addresses:</source>
        <translation>Helbideak:</translation>
    </message>
    <message>
        <location line="-985"/>
        <source>Speed Limits</source>
        <translation>Abiadura Mugak</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Baliogabetu abiadura muga arruntak eskuz edo programatutako orduetan&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>&amp;Scheduled times:</source>
        <translation>&amp;Programatutako orduak:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>&amp;On days:</source>
        <translation>Eg&amp;unak:</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+381"/>
        <source>Every Day</source>
        <translation>Egunero</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Lanegunak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Asteburuak</translation>
    </message>
    <message>
        <location line="-235"/>
        <source>Sunday</source>
        <translation>Igandea</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Monday</source>
        <translation>Astelehena</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tuesday</source>
        <translation>Asteartea</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Wednesday</source>
        <translation>Asteazkena</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Thursday</source>
        <translation>Osteguna</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Friday</source>
        <translation>Ostirala</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saturday</source>
        <translation>Larunbata</translation>
    </message>
    <message numerus="yes">
        <location line="+463"/>
        <source>%1 minute(s)</source>
        <extracomment>Spin box format, &quot;Stop seeding if idle for: [ 5 minutes ]&quot;</extracomment>
        <translation>
            <numerusform>minutu %1</numerusform>
            <numerusform>%1 minutu</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+26"/>
        <source>%1 minute(s) ago</source>
        <extracomment>Spin box format, &quot;Download is inactive if data sharing stopped: [ 5 minutes ago ]&quot;</extracomment>
        <translation>
            <numerusform>duela minutu %1</numerusform>
            <numerusform>duela %1 minutu</numerusform>
        </translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Select &quot;Torrent Done Downloading&quot; Script</source>
        <translation>Aukeratu &quot;Torrentaren Deskarga Amaituta&quot; Script-a</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="+447"/>
        <source>Incoming Peers</source>
        <translation>Barrurako Kideak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>&amp;Barrurako konexioentzako ataka:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>&amp;Erabili UPnP edo NAT-PMP ataka berbidalketa nire router-etik</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Options</source>
        <translation>Aukerak</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-35"/>
        <source>Select &quot;Torrent Done Seeding&quot; Script</source>
        <translation>Aukeratu &quot;Torrentaren Igortzea Amaituta&quot; Script-a</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-520"/>
        <source>Automatically add .torrent files &amp;from:</source>
        <translation>Gehitu &amp;automatikoki .torrent fitxategiak hemendik:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Show the Torrent Options &amp;dialog</source>
        <translation>Erakutsi &amp;Torrent Aukeren leihoa</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Start added torrents</source>
        <translation>&amp;Hasi gehitutako torrentak</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Mo&amp;ve the .torrent file to the trash</source>
        <translation>&amp;Mugitu .torrent fitxategiak zakarrontzira</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Download Queue</source>
        <translation>Deskargen Ilara</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Ma&amp;ximum active downloads:</source>
        <translation>Gehienezko &amp;deskarga aktibo kopurua:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Incomplete</source>
        <translation>Osatugabe</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Seeding</source>
        <translation>Igortzen</translation>
    </message>
    <message>
        <location line="+361"/>
        <source>Trackers to use on all public torrents.

To add a backup URL, add it on the next line after a primary URL.
To add a new primary URL, add it after a blank line.</source>
        <translation>Torrent publiko guztietan erabiltzeko aztarnariak (&apos;&apos;trackers&apos;&apos;).To add a backup URL, add it on the next line after a primary URL.URLaren babeskopia gehitzeko, gehitu hurrengo lerroan, hasierako URLaren ostean.Oinarrizko URL bat gehitzekotan, gehitu lerro zuriaren ostean.</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Remote</source>
        <translation>Urrunekoa</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="+180"/>
        <source>&lt;i&gt;Blocklist contains %Ln rule(s)&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;Blokeo-zerrendak ditu %Ln arau&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Blokeo-zerrendak %Ln arau ditu&lt;/i&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-236"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>&amp;Hautatu zorizko ataka bat Transmission abiarazten den bakoitzean</translation>
    </message>
    <message>
        <location line="-228"/>
        <source>Limits</source>
        <translation>Mugak</translation>
    </message>
    <message>
        <location line="+251"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Gehienezko kide &amp;torrent bakoitzeko:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>Gehienezko kide &amp;guztira:</translation>
    </message>
    <message>
        <location line="-155"/>
        <source>Blocklist</source>
        <translation>Blokeo-zerrenda</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Enable &amp;automatic updates</source>
        <translation>Gaitu &amp;eguneraketa automatikoak</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-215"/>
        <source>Allow encryption</source>
        <translation>Baimendu zifratzea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Hobetsi zifratzea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Behartu zifratzea</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-64"/>
        <source>Privacy</source>
        <translation>Pribatutasuna</translation>
    </message>
    <message>
        <location line="-372"/>
        <source>&amp;to</source>
        <translation>&amp;hona</translation>
    </message>
    <message>
        <location line="+672"/>
        <location line="+6"/>
        <source>Desktop</source>
        <translation>Mahaigaina</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Erakutsi &amp;Transmission ikonoa jakinarazpen eremuan</translation>
    </message>
    <message>
        <location line="-192"/>
        <source>Te&amp;st Port</source>
        <translation>Probatu &amp;Ataka</translation>
    </message>
    <message>
        <location line="-86"/>
        <source>Enable &amp;blocklist:</source>
        <translation>Gaitu blokeo-&amp;zerrenda:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Update</source>
        <translation>&amp;Eguneraketa</translation>
    </message>
    <message>
        <location line="-42"/>
        <source>&amp;Encryption mode:</source>
        <translation>&amp;Zifratze modua:</translation>
    </message>
    <message>
        <location line="+367"/>
        <source>Remote Control</source>
        <translation>Urruneko Kontrola</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Allow &amp;remote access</source>
        <translation>Ahalbidetu &amp;urruneko sarbidea</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>HTTP &amp;port:</source>
        <translation>HTTP &amp;ataka:</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Only allow these IP a&amp;ddresses:</source>
        <translation>A&amp;halbidetu IP helbide hauek bakarrik:</translation>
    </message>
    <message>
        <location line="-969"/>
        <source>&amp;Upload:</source>
        <translation>&amp;Igoera:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Download:</source>
        <translation>&amp;Deskarga:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Alternative Speed Limits</source>
        <translation>Aukerazko Abiadura Mugak</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>U&amp;pload:</source>
        <translation>I&amp;goera:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Do&amp;wnload:</source>
        <translation>J&amp;aitsiera:</translation>
    </message>
    <message>
        <location line="+142"/>
        <source>Reads user clipboard content for torrents</source>
        <translation>Erabiltzailearen arbelaren edukia irakurtzen du torrent-en bila</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Detect new torrents from clipboard</source>
        <translation>Antzeman torrent berriak arbeletik</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Call scrip&amp;t when downloading is completed:</source>
        <translation>Deitu scrip&amp;t-a deskarga osatu denean:</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Call scrip&amp;t when seeding is completed:</source>
        <translation>Deitu scrip&amp;t-a igortzea osatu denean:</translation>
    </message>
    <message>
        <location line="+254"/>
        <source>µTP is a tool for reducing network congestion.</source>
        <translation>µTP sarearen pilaketa txikiagotzeko tresna bat da.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable µ&amp;TP for peer connections</source>
        <translation>Gaitu µ&amp;TP kideen konexioetarako</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Default Public Trackers</source>
        <translation>Aztarnari publiko lehenetsiak</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Start &amp;minimized in notification area</source>
        <translation>&amp;Hasi jakinarazpen eremuan minimizatuta</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Notification</source>
        <translation>Jakinarazpena</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show a notification when torrents are a&amp;dded</source>
        <translation>&amp;Erakutsi jakinarazpen bat torreta gehitzen denean</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show a notification when torrents &amp;finish</source>
        <translation>E&amp;rakutsi jakinarazpen bat torrentak amaitzean</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Play a &amp;sound when torrents finish</source>
        <translation>&amp;Jo soinu bat torrentek amaitzean</translation>
    </message>
    <message>
        <location line="-195"/>
        <source>Peer Limits</source>
        <translation>Kideen Mugak</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>Erabili PE&amp;X kide gehiago bilatzeko</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>PEX konektatuta zauden hartzaileekin kideen zerrendak trukatzeko tresna bat da.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>Erabili &amp;DHT kide gehiago bilatzeko</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>DHT aztarnari gabeko kideak bilatzeko tresna bat da.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>Erabili Hartzaile Aurkikuntza Lo&amp;kala kide gehiago bilatzeko</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>LPD zure sare lokalean kide gehiago bilatzeko tresna bat da.</translation>
    </message>
    <message>
        <location line="-239"/>
        <source>Encryption</source>
        <translation>Zifratzea</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+67"/>
        <source>Select Incomplete Directory</source>
        <translation>Hautatu Osatugabeko Direktorioa</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Select Watch Directory</source>
        <translation>Hautatu Ikusi Direktorioa</translation>
    </message>
    <message>
        <location line="-209"/>
        <source>unknown</source>
        <translation>ezezaguna</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>checking…</source>
        <translation>egiaztatzen...</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>open</source>
        <translation>zabalik</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>closed</source>
        <translation>itxita</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>error</source>
        <translation>errore</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Status: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Status: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Status: &lt;b&gt;%1&lt;/b&gt; (IPv4), &lt;b&gt;%2&lt;/b&gt; (IPv6)</source>
        <translation>Status: &lt;b&gt;%1&lt;/b&gt; (IPv4), &lt;b&gt;%2&lt;/b&gt; (IPv6)</translation>
    </message>
    <message numerus="yes">
        <location line="+96"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rule(s).&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;b&gt;Eguneraketa ondo egin da!&lt;/b&gt;&lt;p&gt;Blokeo-zerrendak orain %Ln arau ditu.&lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Eguneraketa ondo egin da!&lt;/b&gt;&lt;p&gt;Blokeo-zerrendak orain %Ln arau ditu.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist…&lt;/p&gt;</source>
        <translation>&lt;b&gt;Eguneratu Blokeo-zerrenda&lt;/b&gt;&lt;p&gt;Blokeo-zerrenda berria eskuratzen…&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+84"/>
        <source>Select Destination</source>
        <translation>Hautatu Helmuga</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-323"/>
        <source>Adding</source>
        <translation>Gehitzen</translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Download is i&amp;nactive if data sharing stopped:</source>
        <extracomment>Please keep this phrase as short as possible, it&apos;s currently the longest and influences dialog width</extracomment>
        <translation>Deskargatu &amp;geratuta dago datu-partekatzea geratuta badago:</translation>
    </message>
    <message>
        <location line="-123"/>
        <source>Downloading</source>
        <translation>Deskargatzen</translation>
    </message>
    <message>
        <location line="+158"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>&amp;Erantsi &quot;.part&quot; osatugabeko fitxategi izenei</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>&amp;Gorde osatugabeko fitxategiak hemen:</translation>
    </message>
    <message>
        <location line="-100"/>
        <source>Save to &amp;Location:</source>
        <translation>Gorde &amp;Kokaleku honetan:</translation>
    </message>
    <message>
        <location line="+173"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>&amp;Gelditu igortzen maila honetan:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Stop seedi&amp;ng if idle for:</source>
        <translation>Gelditu igortzen &amp;geratuta badago:</translation>
    </message>
    <message>
        <location line="-467"/>
        <source>Transmission Preferences</source>
        <translation>Transmission Hobespenak</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Speed</source>
        <translation>Abiadura</translation>
    </message>
    <message>
        <location line="+604"/>
        <source>Network</source>
        <translation>Sarea</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+114"/>
        <source>Not supported by remote sessions</source>
        <translation>Ez dago sostengaturik urruneko saioentzat</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../Application.cc" line="-266"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>kB/s</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TB/s</source>
        <translation>TB/s</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+7"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location line="+247"/>
        <source>Start Now</source>
        <translation>Abiarazi Orain</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../RelocateDialog.cc" line="+65"/>
        <source>Select Location</source>
        <translation>Hautatu Kokalekua</translation>
    </message>
    <message>
        <location filename="../RelocateDialog.ui" line="+14"/>
        <source>Set Torrent Location</source>
        <translation>Ezarri Torrentaren Kokalekua</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Set Location</source>
        <translation>Ezarri Kokalekua</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>New &amp;location:</source>
        <translation>&amp;Kokaleku berria:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Move from the current folder</source>
        <translation>&amp;Mugitu oraingo karpetatik</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Local data is &amp;already there</source>
        <translation>&amp;Datu lokalak jadanik hor daude</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../Session.cc" line="+502"/>
        <source>Error Renaming Path</source>
        <translation>Akatsa Bidea Berrizendatzerakoan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;p&gt;&lt;b&gt;Unable to rename &quot;%1&quot; as &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please correct the errors and try again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Ezinezkoa berreizendatzea &quot;%1&quot; -&gt; &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Mesedez zuzendu akatsak eta saiatu berriro.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+536"/>
        <source>Error Adding Torrent</source>
        <translation>Errorea Torrenta Gehitzerakoan</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>%1 (copy of %2)</source>
        <translation>%1 ( %2(r)en kopia)</translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>Duplicate Torrent(s)</source>
        <translation>
            <numerusform>Bikoiztu Torrenta</numerusform>
            <numerusform>Bikoiztu Torrentak</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>Unable to add %n duplicate torrent(s)</source>
        <translation>
            <numerusform>Ezin izan da %n bikoiztutako Torrent gehitu</numerusform>
            <numerusform>Ezin izan da %n bikoiztutako Torrent gehitu</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../SessionDialog.ui" line="+14"/>
        <source>Change Session</source>
        <translation>Aldatu Saioa</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Source</source>
        <translation>Jatorria</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Start &amp;Local Session</source>
        <translation>Hasi &amp;Saio Lokala</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>Konektatu &amp;Urruneko Saiora</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Host:</source>
        <translation>&amp;Hostalaria:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Port:</source>
        <translation>&amp;Ataka:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Authentication required</source>
        <translation>&amp;Autentifikazioa behar da</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>Erabiltzaile-&amp;izena:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>&amp;Pasahitza:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Remote root pa&amp;th:</source>
        <translation>Urruneko erro-bidea:</translation>
    </message>
</context>
<context>
    <name>Speed</name>
    <message>
        <location filename="../Speed.h" line="+40"/>
        <location line="+6"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../StatsDialog.ui" line="+14"/>
        <source>Statistics</source>
        <translation>Estatistikak</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Current Session</source>
        <translation>Oraingo Saioa</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+129"/>
        <source>Uploaded:</source>
        <translation>Igota:</translation>
    </message>
    <message>
        <location line="-103"/>
        <location line="+129"/>
        <source>Downloaded:</source>
        <translation>Deskargatuta:</translation>
    </message>
    <message>
        <location line="-103"/>
        <location line="+129"/>
        <source>Ratio:</source>
        <translation>Maila:</translation>
    </message>
    <message>
        <location line="-103"/>
        <location line="+129"/>
        <source>Duration:</source>
        <translation>Iraupena:</translation>
    </message>
    <message>
        <location line="-100"/>
        <source>Total</source>
        <translation>Guztira</translation>
    </message>
    <message numerus="yes">
        <location filename="../StatsDialog.cc" line="+63"/>
        <source>Started %Ln time(s)</source>
        <translation>
            <numerusform>Hasita %Ln aldiz</numerusform>
            <numerusform>Hasita %Ln aldiz</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../Torrent.cc" line="+307"/>
        <source>Verifying local data</source>
        <translation>Datu lokalak egiaztatzen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Downloading</source>
        <translation>Deskargatzen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seeding</source>
        <translation>Igortzen</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Finished</source>
        <translation>Amaituta</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>Pausatuta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Queued for verification</source>
        <translation>Egiaztapenerako ilaratuta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for download</source>
        <translation>Deskargatzeko ilaratuta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for seeding</source>
        <translation>Igortzeko ilaratuta</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Tracker gave a warning: %1</source>
        <translation>Aztarnariak ohar bat eman du: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tracker gave an error: %1</source>
        <translation>Aztarnariak errore bat eman du: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Error: %1</source>
        <translation>Errorea: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../TorrentDelegate.cc" line="+173"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <extracomment>First part of torrent progress string, %1 is the percentage of torrent metadata downloaded</extracomment>
        <translation>Magnetizatutako transferentzia - metadatuak berreskuratzen (%1%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is how much we&apos;ll have when done, %3 is a percentage of the two</extracomment>
        <translation>%1 --&gt; %2 (%3%)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio, %6 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1 --&gt; %2 (%3%), igota %4 (Maila: %5 Helburua: %6)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio</extracomment>
        <translation>%1 --&gt; %2 (%3%), igota %4 (Maila: %5)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio, %4 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1, igota %2 (Maila: %3 Helburua: %4)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio</extracomment>
        <translation>%1, igota %2 (Maila: %3)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source> - %1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation> - %1 gelditzen d(ir)a</translation>
    </message>
    <message>
        <location line="+6"/>
        <source> - Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation> - Gelditzen den denbora ezezaguna</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Ratio: %1</source>
        <translation>Maila: %1</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>%1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation>%1 gelditzen d(ir)a</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation>Gelditzen den denbora ezezaguna</translation>
    </message>
    <message numerus="yes">
        <location line="+40"/>
        <source>Downloading from %Ln peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Jeisten %1 --&gt; %Ln elkarketaturiko hartzailetik</numerusform>
            <numerusform>Deskargatzen %1 --&gt; %Ln konektatutako kidetatik</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+22"/>
        <source>Seeding to %Ln peer(s)</source>
        <translation>
            <numerusform>%Ln hartzailera emaritzen</numerusform>
            <numerusform>%Ln kidetara igortzen</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message numerus="yes">
        <location line="-50"/>
        <source>Downloading metadata from %Ln peer(s) (%1% done)</source>
        <translation>
            <numerusform>Metadatuak jeisten %Ln hartzailetik (%1% eginda)</numerusform>
            <numerusform>Metadatuak deskargatzen %Ln kidetatik (%1% eginda)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+15"/>
        <source>Downloading from %1 of %Ln connected peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Jeisten %1 --&gt; %Ln elkarketaturiko hartzailetik</numerusform>
            <numerusform>Deskargatzen %1 --&gt; %Ln konektatutako kidetatik</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+8"/>
        <source> and %Ln web seed(s)</source>
        <extracomment>Second (optional) part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;, notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> eta %Ln web emaritza</numerusform>
            <numerusform> eta %Ln web-igortze</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+13"/>
        <source>Seeding to %1 of %Ln connected peer(s)</source>
        <translation>
            <numerusform>%1 / %Ln elkarturiko hartzailera emaritzen</numerusform>
            <numerusform>%1 / %Ln konektatutako kidetara igortzen</numerusform>
        </translation>
    </message>
    <message>
        <location line="-95"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Datu lokalak egiaztatzen (%1% aztertuta)</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message numerus="yes">
        <location filename="../TrackerDelegate.cc" line="+220"/>
        <source>Got a list of%1 %Ln peer(s)%2 %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>
            <numerusform>Zerrenda:%1 %Ln hartzaile%2 %3</numerusform>
            <numerusform>Zerrendak%1 %Ln kide%2 zituen orain dela %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Kideen zerrenda eskaera %1denboraz kanpo%2 %3 ; berriz saiatuko da</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Errorea gertatu da: %1&quot;%2&quot;%3 %4</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>Ez dago eguneraketarik programatuta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Kide gehiagorengatik galdetzen: %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for more peers</source>
        <translation>Kide gehiagoengatik galdetzeko ilaratuta</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Asking for peer counts now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Kide kopuruaz orain galdetzen… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="-37"/>
        <source>Tracker had%1 %Ln seeder(s)%2</source>
        <extracomment>First part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup</extracomment>
        <translation>
            <numerusform>Aztarnariak du%1 %Ln emale%2</numerusform>
            <numerusform>Aztarnariak %1 %Ln igorle %2 ditu</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source> and%1 %Ln leecher(s)%2 %3 ago</source>
        <extracomment>Second part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup, %3 is duration; notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> eta%1 %Ln izain%2 %3</numerusform>
            <numerusform> eta%1 %Ln izain%2 %3</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tracker had %1no information%2 on peer counts %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Aztarnariak %1ez zuen kideei buruzko argibiderik %2 duela %3</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Zuriketa errorea gertatu da: %1&quot;%2&quot;%3 %4</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Asking for more peers now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Kide gehiago eskatzen orain… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Asking for peer counts in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Kide kopuruaz galdetuko da denbora hau barru: %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for peer counts</source>
        <translation>Kide kopuruaz galdetzeko ilaratuta</translation>
    </message>
</context>
<context>
    <name>TrackersDialog</name>
    <message>
        <location filename="../TrackersDialog.ui" line="+17"/>
        <source>Edit Trackers</source>
        <translation>Editatu Aztarnariak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tracker Announce URLs</source>
        <translation>Aztarnariak iragartzeko URLak</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>To add a backup URL, add it on the next line after a primary URL.</source>
        <translation>URLaren segurtasun-kopia gehitzekotan, gehitu hurrengo lerroan, oinarrizko URLaren ostean.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>To add a new primary URL, add it after a blank line.</source>
        <translation>URL nagusi berri bat gehitzeko, errenkada huts baten ondoren gehitu ezazu.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Also see Default Public Trackers in Edit &gt; Preferences &gt; Network</source>
        <translation>Aztarnari publiko lehenetsiak Editatu &gt; Hobespenak &gt; Sarea atalean ere ikusi ditzakezu</translation>
    </message>
</context>
</TS>
